CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
70 lines
2.2 KiB
Plaintext
70 lines
2.2 KiB
Plaintext
// expected-no-diagnostics
|
|
|
|
// RUN: %clang_cc1 -triple x86_64-unknown-linux-gnu -fsyntax-only -verify %s
|
|
// RUN: %clang_cc1 -triple nvptx64-nvidia-cuda -fsyntax-only -fcuda-is-device -verify %s
|
|
|
|
#include "Inputs/cuda.h"
|
|
|
|
struct S {
|
|
__host__ static void operator delete(void*, size_t) {}
|
|
__device__ static void operator delete(void*, size_t) {}
|
|
};
|
|
|
|
__host__ __device__ void test(S* s) {
|
|
// This shouldn't be ambiguous -- we call the host overload in host mode and
|
|
// the device overload in device mode.
|
|
delete s;
|
|
}
|
|
|
|
// Code should work with no explicit declarations/definitions of
|
|
// allocator functions.
|
|
__host__ __device__ void test_default_global_delete_hd(int *ptr) {
|
|
// Again, there should be no ambiguity between which operator delete we call.
|
|
::delete ptr;
|
|
}
|
|
|
|
__device__ void test_default_global_delete(int *ptr) {
|
|
// Again, there should be no ambiguity between which operator delete we call.
|
|
::delete ptr;
|
|
}
|
|
__host__ void test_default_global_delete(int *ptr) {
|
|
// Again, there should be no ambiguity between which operator delete we call.
|
|
::delete ptr;
|
|
}
|
|
|
|
// It should work with only some of allocators (re-)declared.
|
|
__device__ void operator delete(void *ptr);
|
|
|
|
__host__ __device__ void test_partial_global_delete_hd(int *ptr) {
|
|
// Again, there should be no ambiguity between which operator delete we call.
|
|
::delete ptr;
|
|
}
|
|
|
|
__device__ void test_partial_global_delete(int *ptr) {
|
|
// Again, there should be no ambiguity between which operator delete we call.
|
|
::delete ptr;
|
|
}
|
|
__host__ void test_partial_global_delete(int *ptr) {
|
|
// Again, there should be no ambiguity between which operator delete we call.
|
|
::delete ptr;
|
|
}
|
|
|
|
|
|
// We should be able to define both host and device variants.
|
|
__host__ void operator delete(void *ptr) {}
|
|
__device__ void operator delete(void *ptr) {}
|
|
|
|
__host__ __device__ void test_overloaded_global_delete_hd(int *ptr) {
|
|
// Again, there should be no ambiguity between which operator delete we call.
|
|
::delete ptr;
|
|
}
|
|
|
|
__device__ void test_overloaded_global_delete(int *ptr) {
|
|
// Again, there should be no ambiguity between which operator delete we call.
|
|
::delete ptr;
|
|
}
|
|
__host__ void test_overloaded_global_delete(int *ptr) {
|
|
// Again, there should be no ambiguity between which operator delete we call.
|
|
::delete ptr;
|
|
}
|